@@ -1,11 +1,12 @@
 package POE::Component::CPAN::YACSmoke;
 
 use strict;
+use warnings;
 use POE qw(Wheel::Run);
 use Storable;
 use vars qw($VERSION);
 
-$VERSION = '1.20';
+$VERSION = '1.22';
 
 my $GOT_KILLFAM;
 
@@ -46,7 +47,7 @@ sub spawn {
 		      flush	=> '_command',
 		      'package' => '_command',
 	   },
-	   $self => [ qw(_start _spawn_wheel _wheel_error _wheel_closed _wheel_stdout _wheel_stderr _wheel_idle _wheel_kill _sig_child _sig_hup) ],
+	   $self => [ qw(_start _spawn_wheel _wheel_error _wheel_closed _wheel_stdout _wheel_stderr _wheel_idle _wheel_kill _sig_child _sig_handle) ],
 	],
 	heap => $self,
 	( ref($options) eq 'HASH' ? ( options => $options ) : () ),
@@ -106,7 +107,7 @@ sub shutdown {
 
 sub _start {
   my ($kernel,$self) = @_[KERNEL,OBJECT];
-  $kernel->sig( 'HUP', '_sig_hup' );
+  $kernel->sig( 'HUP', '_sig_handle' );
   $self->{session_id} = $_[SESSION]->ID();
   if ( $self->{alias} ) {
 	$kernel->alias_set( $self->{alias} );
@@ -128,13 +129,14 @@ sub _start {
   undef;
 }
 
-sub _sig_hup {
+sub _sig_handle {
   $poe_kernel->sig_handled();
 }
 
 sub _shutdown {
   my ($kernel,$self) = @_[KERNEL,OBJECT];
   $kernel->sig( 'HUP' );
+  $kernel->sig( 'KILL' );
   $kernel->alias_remove( $_ ) for $kernel->alias_list();
   $kernel->refcount_decrement( $self->{session_id} => __PACKAGE__ ) unless $self->{alias};
   $kernel->refcount_decrement( $_->{session}, __PACKAGE__ ) for @{ $self->{job_queue} };
